@@ -47,7 +47,18 @@
 # Locate the global Python where virtualenvwrapper is installed.
 if [ "${VIRTUALENVWRAPPER_PYTHON:-}" = "" ]
 then
-    VIRTUALENVWRAPPER_PYTHON="$(command \which python)"
+    _virtualenvwrapper_python_executable="$(which python3 2>/dev/null)"
+    if [ -n "$_virtualenvwrapper_python_executable" ] && $_virtualenvwrapper_python_executable -m 'virtualenvwrapper.hook_loader' --help >/dev/null 2>&1
+    then
+        VIRTUALENVWRAPPER_PYTHON=$_virtualenvwrapper_python_executable
+    fi
+fi
+if [ "${VIRTUALENVWRAPPER_PYTHON:-}" = "" ]
+then
+    echo -e "ERROR: Python with virtualenvwrapper module not found!
+Either, install virtualenvwrapper module for the default python3 interpreter
+or set VIRTUALENVWRAPPER_PYTHON to the interpreter to use." 1>&2
+    return 1
 fi
 
 # Set the name of the virtualenv app to use.
@@ -102,11 +113,9 @@ fi
 # alias or even a shell function. Under bash and zsh, "builtin" forces
 # the use of a command that is part of the shell itself instead of an
 # alias, function, or external command, while "command" does something
-# similar but allows external commands. Under ksh "builtin" registers
-# a new command from a shared library, but "command" will pick up
-# existing builtin commands. We need to use a builtin for cd because
-# we are trying to change the state of the current shell, so we use
-# "builtin" for bash and zsh but "command" under ksh.
+# similar but allows external commands. We need to use a builtin for
+# cd because we are trying to change the state of the current shell,
+# so we use "builtin".
 function virtualenvwrapper_cd {
     if [ -n "${BASH:-}" ]
     then
@@ -114,8 +123,6 @@ function virtualenvwrapper_cd {
     elif [ -n "${ZSH_VERSION:-}" ]
     then
         builtin \cd -q "$@"
-    else
-        command \cd "$@"
     fi
 }
 
@@ -426,7 +433,7 @@ function mkvirtualenv {
             -a)
                 i=$(( $i + 1 ))
                 project="${in_args[$i]}"
-                if [ ! -d "$project" ]
+                if [ ! -d "${project}" ]
                 then
                     echo "Cannot associate project with $project, it is not a directory" 1>&2
                     return 1
@@ -461,7 +468,7 @@ function mkvirtualenv {
         i=$(( $i + 1 ))
     done
 
-    if [ ! -z $interpreter ]
+    if [ ! -z "$interpreter" ]
     then
         out_args=( "--python=$interpreter" ${out_args[@]} )
     fi;
@@ -579,7 +586,7 @@ function virtualenvwrapper_show_workon_options {
         | command \tr "\n" " " \
         | command \sed "s|/$VIRTUALENVWRAPPER_ENV_BIN_DIR/activate |/|g" \
         | command \tr "/" "\n" \
-        | command \sed "/^\s*$/d" \
+        | command \sed "/^[[:space:]]*$/d" \
         | (unset GREP_OPTIONS; command \grep -E -v '^\*$') 2>/dev/null
 }
 
@@ -752,16 +759,14 @@ function workon {
     # before switching so we use our override function,
     # if it exists, but make sure it's the deactivate function
     # we set up
-    type deactivate >/dev/null 2>&1
-    if [ $? -eq 0 ]
-    then
+    ! type deactivate >/dev/null 2>&1 || {
         typeset -f deactivate | grep 'typeset env_postdeactivate_hook' >/dev/null 2>&1
         if [ $? -eq 0 ]
         then
             deactivate
             unset -f deactivate >/dev/null 2>&1
         fi
-    fi
+    }
 
     virtualenvwrapper_run_hook "pre_activate" "$env_name"
 
@@ -815,7 +820,7 @@ function virtualenvwrapper_get_python_version {
 
 # Prints the path to the site-packages directory for the current environment.
 function virtualenvwrapper_get_site_packages_dir {
-    "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_ENV_BIN_DIR/python" -c "import distutils.sysconfig; print(distutils.sysconfig.get_python_lib())"
+    "$VIRTUAL_ENV/$VIRTUALENVWRAPPER_ENV_BIN_DIR/python" -c "import sysconfig; print(sysconfig.get_path('platlib'))"
 }
 
 # Path management for packages outside of the virtual env.
@@ -929,22 +934,6 @@ function lssitepackages {
     fi
 }
 
-# Toggles the currently-active virtualenv between having and not having
-# access to the global site-packages.
-#:help:toggleglobalsitepackages: turn access to global site-packages on/off
-function toggleglobalsitepackages {
-    virtualenvwrapper_verify_workon_home || return 1
-    virtualenvwrapper_verify_active_environment || return 1
-    typeset no_global_site_packages_file="`virtualenvwrapper_get_site_packages_dir`/../no-global-site-packages.txt"
-    if [ -f $no_global_site_packages_file ]; then
-        rm $no_global_site_packages_file
-        [ "$1" = "-q" ] || echo "Enabled global site-packages"
-    else
-        touch $no_global_site_packages_file
-        [ "$1" = "-q" ] || echo "Disabled global site-packages"
-    fi
-}
-
 #:help:cpvirtualenv: duplicate the named virtualenv to make a new one
 function cpvirtualenv {
     virtualenvwrapper_verify_workon_home || return 1
@@ -1291,9 +1280,28 @@ function wipeenv {
     if [ -n "$(cat "$req_file")" ]
     then
         echo "Uninstalling packages:"
-        cat "$req_file"
         echo
-        pip uninstall -y $(cat "$req_file" | grep -v '^-f' | sed 's/>/=/g' | cut -f1 -d=)
+        while read line; do
+            typeset pkg=""
+            if [[ "$line" =~ ^-f ]]; then
+                # ignore lines starting -f which pip sometimes
+                # includes and that do not point to specific
+                # dependencies
+                continue
+            fi
+            if [[ "$line" =~ ^-e ]]; then
+                # fix lines pointing to editable packages, which look like:
+                # -e git+ssh://git@github.com/python-virtualenvwrapper/virtualenvwrapper.git@1dc9e5f52102f0133b804c0c8a6b76c55db908bf#egg=testpackage&subdirectory=tests/testpackage
+                # and parse out the egg name to pass to pip
+                pkg=$(echo "$line" | cut -f2 -d' ' | sed -e 's|&subdirectory.*||g' -e 's|.*egg=||g')
+            else
+                # Strip version specifiers off of the end of the line
+                # to keep only the package name.
+                pkg=$(echo "$line" | sed -e 's/[<>!=].*//g')
+            fi
+            echo $pkg
+            pip uninstall -y "$pkg"
+        done < "$req_file"
     else
         echo "Nothing to remove."
     fi
@@ -1326,8 +1334,13 @@ function allvirtualenv {
     unset IFS
 }
 
+function _virtualenvwrapper_version {
+    "$VIRTUALENVWRAPPER_PYTHON" -m 'virtualenvwrapper.hook_loader' --version
+}
+
 #:help:virtualenvwrapper: show this help message
 function virtualenvwrapper {
+    typeset version=$(_virtualenvwrapper_version)
 	cat <<EOF
 
 virtualenvwrapper is a set of extensions to Ian Bicking's virtualenv
@@ -1340,6 +1353,12 @@ For more information please refer to the documentation:
 
     http://virtualenvwrapper.readthedocs.org/en/latest/command_ref.html
 
+Version: $version
+Script: $VIRTUALENVWRAPPER_SCRIPT
+Python: $VIRTUALENVWRAPPER_PYTHON
+WORKON_HOME: $WORKON_HOME
+PROJECT_HOME: $PROJECT_HOME
+
 Commands available:
 
 EOF
